==> maineetloire_20170122_0405.tgz: var/www/vhosts/mag.maine-et-loire.fr/htdocs/wp-content/themes/emag_new/footer.php <==

<!-- footer -->
<footer class="footer" role="contentinfo">
    <?php
    $current_numero = getCurrentNumero();
    $num_colors = get_option('numero_colors');
    $active_color = $num_colors[$current_numero->term_id];
    ?>
    <style>
        h2.title_help {
            background-color: <?php echo $active_color; ?>;
        }
    </style>
    <script>
        jQuery(function () {
            //localStorage.clear();
            var dh_tuto_content = localStorage.getItem('dh_tuto_content');

            if (dh_tuto_content !== "1") {
                localStorage.setItem('dh_tuto_content', "1");
                jQuery("a.trigger-help").trigger("click");
            }
        });
    </script>
    <div id="help-content" class="popup-container" style="display:none">

        <?php
        $tuto = get_post(182);
        
        $image1 = get_field('image_1', 182);
        $image2 = get_field('image_2', 182);
        $image3 = get_field('image_3', 182);
        $image4 = get_field('image_4', 182);
        $image5 = get_field('image_5', 182);
        $image6 = get_field('image_6', 182);
        $image7 = get_field('image_7', 182);
        ?>

        <p class="intro"><span class="welcome">Bienvenue </span>Vous trouverez ci-dessous une aide de navigation pour vous permettre de mieux appréhender votre E-Mag.</p>

        <article class="help_content">
            <h3>Naviguer</h3>
            <!-- Horizontal swipe -->
            <div class="img_container img_container_1"><img src="<?php echo $image1[url]; ?>" alt="<?php echo $image1[alt]; ?>" width="236" height="178" /></div>
            <div class="text_container">
                <p>
                    <strong>Sur tablette, glisser de droite à gauche</strong> pour avancer de façon linéaire. Les pages se succèdent en respectant la progression du magazine.
                </p>
            </div>
            <!-- Vertical swipe -->
            <div class="img_container img_container_2"><img src="<?php echo $image2[url]; ?>" alt="<?php echo $image2[alt]; ?>" width="236" height="181" /></div>
            <div class="text_container">
                <p>
                    <strong>Glisser verticalement</strong> pour faire défiler les textes (colonne de droite) et les contenus associés (colonne de gauche) : photos, vidéos, diaporamas, encadrés…
                </p>
            </div>
            <!-- VERTICAL LAYOUT -->
            <div class="img_container img_container_3" style="margin-bottom: 10px;"><img src="<?php echo $image3[url]; ?>" alt="<?php echo $image3[alt]; ?>" width="175" height="233" /></div>
            <div class="text_container">
                <p>
                    <strong>Orienter verticalement votre tablette </strong>pour profiter du texte en plein écran.
                </p>
            </div>
            <!-- Desktop navigation -->
            <div class="img_container img_container_4"><img src="<?php echo $image4[url]; ?>" alt="<?php echo $image4[alt]; ?>" width="276" height="207" /></div>
            <div class="text_container">
                <p>
                    <strong>Sur ordinateur, glisser/déposer avec la souris</strong> pour avancer de façon linéaire. Les pages se succèdent en respectant la progression du magazine.
                </p>
            </div>
            <div class="clearfloat"></div>
            <h3>Icônes d’actions</h3>
            <p class="intro">Diverses icônes d'action signalent une interactivité spécifique. Elles permettent d'accéder à différents types de contenus, renvoyer vers de liens externes…</p>

            <div class="img_container icons"><img src="<?php echo $image5[url]; ?>" alt="<?php echo $image5[alt]; ?>" width="368" /></div>
            <div class="text_container icons">
                <p>
                    1. Vidéo<br/>
                    2. Encadré<br/>
                    3. Son<br/>
                    4. Citation<br/>
                    5. Chiffres-clef<br/>
                    6. Diaporama<br/>
                    7. Lien externe<br/>
                    8. Partager<br/>
                    9. Commentaire<br/>
                </p>
            </div>
            <div class="clearfloat"></div>
            <h3>Barre de menu principale</h3>
            <p class="intro">La barre de menu permet d'accéder facilement aux différentes rubriques et articles. Grâce à l'outil de recherche ou le déroulé rapide, vous pouvez facilement trouver un contenu précis.</p>

            <div class="img_container img_container_5"><img src="<?php echo $image6[url]; ?>" alt="<?php echo $image6[alt]; ?>" width="236" height="177" /><img class="rounded-img" src="<?php echo $image7[url]; ?>" alt="<?php echo $image7[alt]; ?>" width="175" height="160" /></div>
            <div class="text_container">
                <p>
                    <strong>1. Rechercher</strong>
                    Pour rechercher un contenu, cliquer sur la loupe, entrer votre requête et cliquer sur la loupe une nouvelle fois.<br/>
                    <strong>2. Afficher le déroulé rapide</strong>
                    Le déroulé rapide permet de visualiser toutes les rubriques et tous les articles et d'y accéder directement.<br/>
                    <strong>3. Accéder au sommaire du numéro</strong>
                    Le sommaire interactif permet d’accéder rapidement aux articles.<br/>
                </p>
            </div>
        </article>
    </div>

</footer>
<!-- /footer -->
<?php wp_footer(); ?>

<?php
// Code piwik
$piwik = get_option("dh_js_code_piwik");
if (!empty($piwik)) {
    echo $piwik;
}

/*
  <!-- analytics -->
  <script>
  (function(f,i,r,e,s,h,l){i['GoogleAnalyticsObject']=s;f[s]=f[s]||function(){
  (f[s].q=f[s].q||[]).push(arguments)},f[s].l=1*new Date();h=i.createElement(r),
  l=i.getElementsByTagName(r)[0];h.async=1;h.src=e;l.parentNode.insertBefore(h,l)
  })(window,document,'script','//www.google-analytics.com/analytics.js','ga');
  ga('create', 'UA-XXXXXXXX-XX', 'yourdomain.com');
  ga('send', 'pageview');
  </script>
 */
?>
<div class="bg-repeat"> </div>
<script src="<?php echo get_template_directory_uri(); ?>/js/bootstrap.js"></script>
</div>
<!-- AJOUT -->
<!-- <link rel="import" href="http://www.maine-et-loire.fr/fileadmin/dep49-header-footer/elements/elements.html">
<script src="http://www.maine-et-loire.fr/fileadmin/dep49-header-footer/js/polyfillLoader.js"></script>  

<style>
#headerContrast {
    display: none;
}
ul.subLevel1.active.style-scope.dep49-header {
    background-color: white;
}

	</style>

	<dep49-footer></dep49-footer>  -->
<!-- fin AJOUT -->
</body>
</html>

==> maineetloire_20170129_0405.tgz: var/www/vhosts/mag.maine-et-loire.fr/htdocs/wp-content/themes/emag_new/footer.php <==

<!-- footer -->
<footer class="footer" role="contentinfo">
    <?php
    $current_numero = getCurrentNumero();
    $num_colors = get_option('numero_colors');
    $active_color = $num_colors[$current_numero->term_id];
    ?>
    <style>
        h2.title_help {
            background-color: <?php echo $active_color; ?>;
        }
    </style>
    <script>
        jQuery(function () {
            //localStorage.clear();
            var dh_tuto_content = localStorage.getItem('dh_tuto_content');

            if (dh_tuto_content !== "1") {
                localStorage.setItem('dh_tuto_content', "1");
                jQuery("a.trigger-help").trigger("click");
            }
        });
    </script>
    <div id="help-content" class="popup-container" style="display:none">

        <?php
        $tuto = get_post(182);

        $image1 = get_field('image_1', 182);
        $image2 = get_field('image_2', 182);
        $image3 = get_field('image_3', 182);
        $image4 = get_field('image_4', 182);
        $image5 = get_field('image_5', 182);
        $image6 = get_field('image_6', 182);
        $image7 = get_field('image_7', 182);
        ?>

        <p class="intro"><span class="welcome">Bienvenue </span>Vous trouverez ci-dessous une aide de navigation pour vous permettre de mieux appréhender votre E-Mag.</p>

        <article class="help_content">
            <h3>Naviguer</h3>
            <!-- Horizontal swipe -->
            <div class="img_container img_container_1">
                <?php
                if (isset($image1[url])) {
                    echo '<img src="' . $image1[url] . '"';
                    if (isset($image1[alt])) {
                        echo ' alt="' . $image1[alt] . '"';
                    }
                    echo ' width="236" height="178"/>';
                }
                ?>
            </div>
            <div class="text_container">
                <p>
                    <strong>Sur tablette, glisser de droite à gauche</strong> pour avancer de façon linéaire. Les pages se succèdent en respectant la progression du magazine.
                </p>
            </div>
            <!-- Vertical swipe -->
            <div class="img_container img_container_2">
                <?php
                if (isset($image2[url])) {
                    echo '<img src="' . $image2[url] . '"';
                    if (isset($image2[alt])) {
                        echo ' alt="' . $image2[alt] . '"';
                    }
                    echo ' width="236" height="181"/>';
                }
                ?>
            </div>
            <div class="text_container">
                <p>
                    <strong>Glisser verticalement</strong> pour faire défiler les textes (colonne de droite) et les contenus associés (colonne de gauche) : photos, vidéos, diaporamas, encadrés…
                </p>
            </div>
            <!-- VERTICAL LAYOUT -->
            <div class="img_container img_container_3" style="margin-bottom: 10px;">
                <?php
                if (isset($image3[url])) {
                    echo '<img src="' . $image3[url] . '"';
                    if (isset($image3[alt])) {
                        echo ' alt="' . $image3[alt] . '"';
                    }
                    echo ' width="175" height="233"/>';
                }
                ?>
            </div>
            <div class="text_container">
                <p>
                    <strong>Orienter verticalement votre tablette </strong>pour profiter du texte en plein écran.
                </p>
            </div>
            <!-- Desktop navigation -->
            <div class="img_container img_container_4">
                <?php
                if (isset($image4[url])) {
                    echo '<img src="' . $image4[url] . '"';
                    if (isset($image4[alt])) {
                        echo ' alt="' . $image4[alt] . '"';
                    }
                    echo ' width="276" height="207"/>';
                }
                ?>
            </div>
            <div class="text_container">
                <p>
                    <strong>Sur ordinateur, glisser/déposer avec la souris</strong> pour avancer de façon linéaire. Les pages se succèdent en respectant la progression du magazine.
                </p>
            </div>
            <div class="clearfloat"></div>
            <h3>Icônes d’actions</h3>
            <p class="intro">Diverses icônes d'action signalent une interactivité spécifique. Elles permettent d'accéder à différents types de contenus, renvoyer vers de liens externes…</p>

            <div class="img_container icons">
                <?php
                if (isset($image5[url])) {
                    echo '<img src="' . $image5[url] . '"';
                    if (isset($image5[alt])) {
                        echo ' alt="' . $image5[alt] . '"';
                    }
                    echo ' width="368"/>';
                }
                ?>
            </div>
            <div class="text_container icons">
                <p>
                    1. Vidéo<br/>
                    2. Encadré<br/>
                    3. Son<br/>
                    4. Citation<br/>
                    5. Chiffres-clef<br/>
                    6. Diaporama<br/>
                    7. Lien externe<br/>
                    8. Partager<br/>
                    9. Commentaire<br/>
                </p>
            </div>
            <div class="clearfloat"></div>
            <h3>Barre de menu principale</h3>
            <p class="intro">La barre de menu permet d'accéder facilement aux différentes rubriques et articles. Grâce à l'outil de recherche ou le déroulé rapide, vous pouvez facilement trouver un contenu précis.</p>

            <div class="img_container img_container_5">
                <?php
                if (isset($image6[url])) {
                    echo '<img src="' . $image6[url] . '"';
                    if (isset($image6[alt])) {
                        echo ' alt="' . $image6[alt] . '"';
                    }
                    echo ' width="236" height="177" />';
                }
                ?>
                <?php
                if (isset($image7[url])) {
                    echo '<img class="rounded-img" src="' . $image7[url] . '"';
                    if (isset($image7[alt])) {
                        echo ' alt="' . $image7[alt] . '"';
                    }
                    echo ' width="175" height="160" />';
                }
                ?></div>
            <div class="text_container">
                <p>
                    <strong>1. Rechercher</strong>
                    Pour rechercher un contenu, cliquer sur la loupe, entrer votre requête et cliquer sur la loupe une nouvelle fois.<br/>
                    <strong>2. Afficher le déroulé rapide</strong>
                    Le déroulé rapide permet de visualiser toutes les rubriques et tous les articles et d'y accéder directement.<br/>
                    <strong>3. Accéder au sommaire du numéro</strong>
                    Le sommaire interactif permet d’accéder rapidement aux articles.<br/>
                </p>
            </div>
        </article>
    </div>

</footer>
<!-- /footer -->
<?php wp_footer(); ?>

<?php
// Code piwik
$piwik = get_option("dh_js_code_piwik");
if (!empty($piwik)) {
    echo $piwik;
}

/*
  <!-- analytics -->
  <script>
  (function(f,i,r,e,s,h,l){i['GoogleAnalyticsObject']=s;f[s]=f[s]||function(){
  (f[s].q=f[s].q||[]).push(arguments)},f[s].l=1*new Date();h=i.createElement(r),
  l=i.getElementsByTagName(r)[0];h.async=1;h.src=e;l.parentNode.insertBefore(h,l)
  })(window,document,'script','//www.google-analytics.com/analytics.js','ga');
  ga('create', 'UA-XXXXXXXX-XX', 'yourdomain.com');
  ga('send', 'pageview');
  </script>
 */
?>
<div class="bg-repeat"> </div>
<script src="<?php echo get_template_directory_uri(); ?>/js/bootstrap.js"></script>
</div>
</body>
</html>
